function [ ang_est, Es, En] = ESPRIT_ISA( Y, K, idx1, idx2)
%ESPRIT ALGORITHM ON DATA Y, ESTIMATING K ANGLES FROM ULA OF COHERENT SUBARRAYS OF
%TWO ELEMENTS. FIRST ELEMENTS OF EACH SUBARRAY AT INDEXES idx1, OTHER
%ELEMENTS IN idx2
% Y         MEASUREMENTS
% K         NUMBER OF DOAS
% idx1      LOCATION OF FIRST ELEMENT OF EACH SUBARRAY
% idx2      LOCATION OF SECOND ELEMENT OF EACH SUBARRAY
% ang_est   ESTIMATE OF DOAS
% Es        SIGNAL SUBSPACE
% En        NOISE SUBSPACE

% Ryy         = cov(transpose(Y));
ang_est     = zeros(K,1);
Ryy         = Y*Y';
[E,D]       = eig(Ryy);
[~,idx]     = sort(diag(D),'descend');
for i = 1:K
    Es          = E(:,idx(i));
    En          = E(:,1:end-K);
    Es1         = Es(idx1,:);
    Es2         = Es(idx2,:);
    Psi         = pinv(Es1)*Es2;
    tmp         = (angle(eig(Psi)))/pi;
    ang_est(i)  = (asind((tmp)));
%     ang_est(i)  = tmp*90;

end
end
